import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { BatchVO, BatchForm, BatchQuery } from '@/api/qms/batch/types';

/**
 * 查询批次管理列表
 * @param query
 * @returns {*}
 */

export const listBatch = (query?: BatchQuery): AxiosPromise<BatchVO[]> => {
  return request({
    url: '/qms/batch/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询所有产品型号
 * @param query
 */
export const listProdModels = () => {
  return request({
    url: '/qms/batch/distinctProductModels',
    method: 'get'
  });
};

/**
 * 查询批次管理详细
 * @param id
 */
export const getBatch = (id: string | number): AxiosPromise<BatchVO> => {
  return request({
    url: '/qms/batch/' + id,
    method: 'get'
  });
};

/**
 * 新增批次管理
 * @param data
 */
export const addBatch = (data: BatchForm) => {
  return request({
    url: '/qms/batch',
    method: 'post',
    data: data
  });
};

/**
 * 修改批次管理
 * @param data
 */
export const updateBatch = (data: BatchForm) => {
  return request({
    url: '/qms/batch',
    method: 'put',
    data: data
  });
};

/**
 * 删除批次管理
 * @param id
 */
export const delBatch = (id: string | number | Array<string | number>) => {
  return request({
    url: '/qms/batch/' + id,
    method: 'delete'
  });
};
